diff --git a/api/rql/options.go b/api/rql/options.go
index c5bf06e13..90174add5 100644
--- a/api/rql/options.go
+++ b/api/rql/options.go
@@ -2,8 +2,24 @@ package rql
// Options represent the RQL's options
type Options struct {
+ // Mindepth is the minimum depth. Descendants at lesser depths are not included
+ // in the RQL's returned list of entries.
+ //
+ // Depth starts from 0. For example, given paths "foo", "foo/bar", "foo/bar/baz",
+ // assume "foo" is the start path. Then "foo" is at depth 0, "foo/bar" is at depth 1,
+ // "foo/bar/baz" is at depth 2, etc.
Mindepth int
+ // Maxdepth is the maximum depth. Descendants at greater depths are not included
+ // in the RQL's returned list of entries. See Mindepth's comments to understand how
+ // depth is calculated.
Maxdepth int
+ // Fullmeta is short for "full metadata". If set, then meta primary queries act on
+ // the entry's full metadata, and the returned list of entries will include the entry's
+ // full metadata. If unset then the RQL uses the partial metadata instead.
+ //
+ // Note that setting Fullmeta could result in O(N) extra requests to fetch the metadata,
+ // where N is the number of visited entries. Using the partial metadata (unsetting Fullmeta)
+ // does not result in any extra request.
Fullmeta bool
}
diff --git a/docs/README.md b/docs/README.md
index 67b0a6030..51a6945c4 100644
--- a/docs/README.md
+++ b/docs/README.md
@@ -31,8 +31,8 @@ go get -u github.com/go-swagger/go-swagger/cmd/swagger
Then run it and [redoc-cli](https://github.com/Rebilly/ReDoc/blob/master/cli/README.md) from the project root to update the static docs page.
```
-swagger generate spec > docs/docs/api.json
-npx redoc-cli bundle docs/docs/api.json -o docs/docs/api.html --options.nativeScrollbars
+swagger generate spec > docs/_docs/api.json
+npx redoc-cli bundle docs/_docs/api.json -o docs/_docs/api.html --options.nativeScrollbars
```
## Extending the screencasts
diff --git a/docs/_docs/api.html b/docs/_docs/api.html
index 6c8c71165..d70b497a4 100644
--- a/docs/_docs/api.html
+++ b/docs/_docs/api.html
@@ -15,10 +15,10 @@
@@ -257,7 +272,7 @@
diff --git a/api/find.go b/api/find.go
index 0a0111124..69fae67b9 100644
--- a/api/find.go
+++ b/api/find.go
@@ -13,9 +13,24 @@ import (
"github.com/puppetlabs/wash/plugin"
)
-// swagger:route GET /fs/find find listEntries
+// swagger:response
+//nolint:deadcode,unused
+type findResponse struct {
+ // in: body
+ Entries []apitypes.Entry
+}
+
+// swagger:parameters findResponse
+//nolint:deadcode,unused
+type findParams struct {
+ params
+ rql.Options
+}
+
+// swagger:route GET /fs/find find findResponse
//
// Recursively descends the given path returning it and its children.
//
// Consumes:
// - application/json
@@ -13,9 +13,24 @@ import (
//
-// Recursively descends the given path returning it and its children.
+// Recursively descends the given path, returning all children that satisfy
+// the given RQL query.
//
// Consumes: